@@ -210,7 +210,7 @@ Dezi.Admin.Index.createViewer = function(json) {
 }
 
 Dezi.Admin.Stats.TimesChart = function() {
-    var search_path = '/search';
+    var search_path = '*/search';
     if (Ext.isDefined(DEZI_ABOUT.search)) {
         search_path = DEZI_ABOUT.search.replace(DEZI_ABOUT.api_base_url,'*');
     }
